import { css, LitElement, html } from 'lit-element';

const BsButtonGroupCss = css`
    :host {
        position: var(--btn-group-position, relative);
        display: var(--btn-group-display, inline-flex);
        vertical-align: var(--btn-group-vertical-align, middle);
        --btn-position: var(--btn-group-btn-position, relative);
        --btn-flex: var(--btn-group-btn-flex, 0 1 auto);
        --btn-z-index-hover: var(--btn-group-btn-z-index-hover, 1);
        --btn-z-index-active: var(--btn-group-btn-z-index-active, 1);
    }
`;

const BsButtonGroupSizeCss = css`
    :host([size="small"]) {
        --btn-pd-top: var(--btn-group-pd-top-sm, 0.25rem);
        --btn-pd-bottom: var(--btn-group-pd-bottom-sm, 0.25rem);
        --btn-pd-left: var(--btn-group-pd-left-sm, 0.5rem);
        --btn-pd-right: var(--btn-group-pd-right-sm, 0.5rem);
        --btn-font-size: var(--btn-group-font-size-sm, 0.875rem);
        --btn-line-height: var(--btn-group-line-height-sm, 1.5);
        --btn-bd-top-left-radius: var(--btn-group-top-left-radius-sm, 0.2rem);
        --btn-bd-bottom-left-radius: var(
            --btn-group-bottom-left-radius-sm,
            0.2rem
        );
        --btn-bd-top-right-radius: var(--btn-group-top-right-radius-sm, 0.2rem);
        --btn-bd-bottom-right-radius: var(
            --btn-group-bottom-left-radius-sm,
            0.2rem
        );
    }

    :host([size="large"]) {
        --btn-pd-top: var(--btn-group-pd-top-lg, 0.5rem);
        --btn-pd-bottom: var(--btn-group-pd-bottom-lg, 0.5rem);
        --btn-pd-left: var(--btn-group-pd-left-lg, 1rem);
        --btn-pd-right: var(--btn-group-pd-right-lg, 1rem);
        --btn-font-size: var(--btn-group-font-size-lg, 1.25rem);
        --btn-line-height: var(--btn-group-line-height-lg, 1.5);
        --btn-bd-top-left-radius: var(--btn-group-top-left-radius-lg, 0.3rem);
        --btn-bd-bottom-left-radius: var(
            --btn-group-bottom-left-radius-lg,
            0.3rem
        );
        --btn-bd-top-right-radius: var(--btn-group-top-right-radius-lg, 0.3rem);
        --btn-bd-bottom-right-radius: var(
            --btn-group-bottom-left-radius-lg,
            0.3rem
        );
    }
`;

const BsButtonGroupDirectionCss = css`
    :host([direction="horizontal"]) ::slotted(:not(:last-child)) {
        --btn-bd-top-right-radius: var(
            --btn-group-btn-bd-top-right-radius-h,
            0
        );
        --btn-bd-bottom-right-radius: var(
            --btn-group-btn-bd-bottom-right-radius-h,
            0
        );
    }

    :host([direction="horizontal"]) ::slotted(:not(:first-child)) {
        --btn-bd-top-left-radius: var(--btn-group-btn-bd-top-left-radius-h, 0);
        --btn-bd-bottom-left-radius: var(
            --btn-group-btn-bd-botom-left-radius-h,
            0
        );
    }

    :host([direction="vertical"]) {
        flex-direction: var(--btn-group-flex-direction-v, column);
        align-items: var(--btn-group-align-items-v, flex-start);
        justify-content: var(--btn-group-justify-content-v, center);
        --btn-width: var(--btn-group-btn-width-v, 100%);
    }

    :host([direction="vertical"]) ::slotted(:not(:last-child)) {
        --btn-bd-bottom-left-radius: var(
            --btn-group-btn-bd-bottom-left-radius-v,
            0
        );
        --btn-bd-bottom-right-radius: var(
            --btn-group-btn-bd-bottom-right-radius-v,
            0
        );
    }

    :host([direction="vertical"]) ::slotted(:not(:first-child)) {
        --btn-bd-top-left-radius: var(--btn-group-btn-bd-top-left-radius-v, 0);
        --btn-bd-top-right-radius: var(
            --btn-group-btn-bd-top-right-radius-v,
            0
        );
    }
`;

const BsButtonGroupRebootCss = css`
    *,
    *::before,
    *::after {
        box-sizing: border-box;
    }

    :host,
    :host::before,
    :host::after {
        box-sizing: border-box;
    }
`;

class BsButtonGroup extends LitElement {
  static get properties() {
    return {
      direction: {
        type: String,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsButtonGroupRebootCss, BsButtonGroupCss, BsButtonGroupSizeCss, BsButtonGroupDirectionCss];
  }

  render() {
    return html`
            <slot></slot>
        `;
  }

  constructor() {
    super();
    this.direction = "horizontal";
  }
  /**
   * The aria role is added to the host element
   *
   * @param   {Map}  _updatedProperties  the Map with updated properties
   * @return  {void}
   */


  firstUpdated(_updatedProperties) {
    super.firstUpdated(_updatedProperties);

    this._addAriaRole();
  }
  /**
   * Adds an arial role attribute with value of 'group'
   *
   * @return  {void}
   */


  _addAriaRole() {
    this.setAttribute("role", "group");
  }

}
if (!window.customElements.get("bs-button-group")) window.customElements.define("bs-button-group", BsButtonGroup);

const BsButtonToolbarCss = css`
    :host {
        display: flex;
        flex-wrap: wrap;
        justify-content: flex-start;
        --bs-input-group-width: auto;
    }
`;

class BsButtonToolbar extends LitElement {
  static get styles() {
    return [BsButtonGroupRebootCss, BsButtonToolbarCss];
  }

  render() {
    return html`
            <slot></slot>
        `;
  }
  /**
   * The aria role is added to the host element
   *
   * @param   {Map}  _updatedProperties  the Map with updated properties
   * @return  {void}
   */


  firstUpdated(_updatedProperties) {
    super.firstUpdated(_updatedProperties);

    this._addAriaRole();
  }
  /**
   * Adds an arial role attribute with value of 'toolbar'
   *
   * @return  {void}
   */


  _addAriaRole() {
    this.setAttribute("role", "toolbar");
  }

}
if (!window.customElements.get("bs-button-toolbar")) window.customElements.define("bs-button-toolbar", BsButtonToolbar);

export { BsButtonGroup, BsButtonGroupDirectionCss, BsButtonGroupRebootCss, BsButtonGroupSizeCss, BsButtonToolbar, BsButtonToolbarCss };
//# sourceMappingURL=index.js.map
